"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var request = require("request");
/**
 * A default set of user agent patterns for bots/crawlers that do not perform
 * well with pages that require JavaScript.
 */
exports.botUserAgents = [
    'Baiduspider',
    'bingbot',
    'Embedly',
    'facebookexternalhit',
    'LinkedInBot',
    'outbrain',
    'pinterest',
    'quora link preview',
    'rogerbot',
    'showyoubot',
    'Slackbot',
    'TelegramBot',
    'Twitterbot',
    'vkShare',
    'W3C_Validator',
    'WhatsApp',
];
/**
 * A default set of file extensions for static assets that do not need to be
 * proxied.
 */
var staticFileExtensions = [
    'ai', 'avi', 'css', 'dat', 'dmg', 'doc', 'doc', 'exe', 'flv',
    'gif', 'ico', 'iso', 'jpeg', 'jpg', 'js', 'less', 'm4a', 'm4v',
    'mov', 'mp3', 'mp4', 'mpeg', 'mpg', 'pdf', 'png', 'ppt', 'psd',
    'rar', 'rss', 'svg', 'swf', 'tif', 'torrent', 'ttf', 'txt', 'wav',
    'wmv', 'woff', 'xls', 'xml', 'zip',
];
/**
 * Create a new Express middleware function that proxies requests to a
 * Rendertron bot rendering service.
 */
function makeMiddleware(options) {
    if (!options || !options.proxyUrl) {
        throw new Error('Must set options.proxyUrl.');
    }
    var proxyUrl = options.proxyUrl;
    if (!proxyUrl.endsWith('/')) {
        proxyUrl += '/';
    }
    var userAgentPattern = options.userAgentPattern || new RegExp(exports.botUserAgents.join('|'), 'i');
    var excludeUrlPattern = options.excludeUrlPattern ||
        new RegExp("\\.(" + staticFileExtensions.join('|') + ")$", 'i');
    var injectShadyDom = !!options.injectShadyDom;
    // The Rendertron service itself has a hard limit of 10 seconds to render, so
    // let's give a little more time than that by default.
    var timeout = options.timeout || 11000; // Milliseconds.
    return function rendertronMiddleware(req, res, next) {
        var ua = req.headers['user-agent'];
        if (ua === undefined || !userAgentPattern.test(ua) ||
            excludeUrlPattern.test(req.path)) {
            next();
            return;
        }
        var incomingUrl = req.protocol + '://' + req.get('host') + req.originalUrl;
        var renderUrl = proxyUrl + encodeURIComponent(incomingUrl);
        if (injectShadyDom) {
            renderUrl += '?wc-inject-shadydom=true';
        }
        request({ url: renderUrl, timeout: timeout }, function (e) {
            if (e) {
                console.error("[rendertron middleware] " + e.code + " error fetching " + renderUrl);
                next();
            }
        }).pipe(res);
    };
}
exports.makeMiddleware = makeMiddleware;
//# sourceMappingURL=middleware.js.map